@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.047-10-g939f134
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.048-9-gf5bf9ab
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.048';
+our $VERSION = '0.049';
 
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
@@ -21,7 +21,6 @@ use Cwd;
 use CPAN::DistnameInfo;
 use HTTP::Tiny;
 use YAML::Tiny;
-use Module::Path 0.18 'module_path';
 use Module::Metadata 1.000023;
 use Encode ();
 use namespace::autoclean;
@@ -100,12 +99,18 @@ sub before_build
 
     if ($self->phase eq 'build')
     {
+        my @extra_modules = $self->_modules_extra;
         my @modules = (
-            $self->_modules_extra,
-            ( $self->check_authordeps ? $self->_authordeps : () ),
-            ( $self->check_all_plugins ? $self->_modules_plugin : () ),
+            @extra_modules,
+            $self->check_authordeps ? $self->_authordeps : (),
+            $self->check_all_plugins ? $self->_modules_plugin : (),
         );
 
+        $self->log([ 'checking for stale %s...', join(', ',
+            @extra_modules ? 'modules' : (),
+            $self->check_authordeps ? 'authordeps' : (),
+            $self->check_all_plugins ? 'plugins' : ())
+        ]);
         $self->_check_modules(sort(uniq(@modules))) if @modules;
     }
 }
@@ -116,8 +121,10 @@ sub after_build
 
     if ($self->phase eq 'build' and $self->check_all_prereqs)
     {
-        my @modules = $self->_modules_prereq;
-        $self->_check_modules(sort(uniq(@modules))) if @modules;
+        if (my @modules = $self->_modules_prereq) {
+            $self->log('checking for stale prerequisites...');
+            $self->_check_modules(sort(uniq(@modules)));
+        }
     }
 }
 
@@ -126,12 +133,20 @@ sub before_release
     my $self = shift;
     if ($self->phase eq 'release')
     {
+        my @extra_modules = $self->_modules_extra;
         my @modules = (
-            $self->_modules_extra,
-            ( $self->check_authordeps ? $self->_authordeps : () ),
-            ( $self->check_all_plugins ? $self->_modules_plugin : () ),
+            @extra_modules,
+            $self->check_authordeps ? $self->_authordeps : (),
+            $self->check_all_plugins ? $self->_modules_plugin : (),
+            $self->check_all_prereqs ? $self->_modules_prereq : (),
         );
-        push @modules, $self->_modules_prereq if $self->check_all_prereqs;
+
+        $self->log([ 'checking for stale %s...', join(', ',
+            @extra_modules ? 'modules' : (),
+            $self->check_authordeps ? 'authordeps' : (),
+            $self->check_all_plugins ? 'plugins' : (),
+            $self->check_all_prereqs ? 'prerequisites' : ())
+        ]);
 
         $self->_check_modules(sort(uniq(@modules))) if @modules;
     }
@@ -170,7 +185,7 @@ sub stale_modules
             next;
         }
 
-        my $path = module_path($module);
+        my $path = Module::Metadata->find_module_by_name($module);
         if (not $path)
         {
             $already_checked{$module}++;
@@ -237,7 +252,6 @@ sub _check_modules
 {
     my ($self, @modules) = @_;
 
-    $self->log('checking for stale modules...');
     my ($stale_modules, $errors) = $self->stale_modules(@modules);
 
     return if not @$errors;
@@ -461,7 +475,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.048
+version 0.049
 
 =head1 SYNOPSIS
 
